==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridSelectionRangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescriptionMetadata } from "./WebGridSelectionRangeDetailDescriptionMetadata";
import { WebGridSelectionRangeEventArgsDescription } from "./WebGridSelectionRangeEventArgsDescription";
/**
 * @hidden
 */
export let WebGridSelectionRangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSelectionRangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSelectionRangeEventArgsDescriptionMetadata.a == null) {
                WebGridSelectionRangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSelectionRangeEventArgsDescriptionMetadata.c(WebGridSelectionRangeEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebGridSelectionRangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridSelectionRangeEventArgsDescriptionMetadata.a);
            WebGridSelectionRangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSelectionRangeEventArgs");
            a.item("Detail", "ExportedType:WebGridSelectionRangeDetail");
        }
        static d(a) {
            WebGridSelectionRangeEventArgsDescriptionMetadata.b(a);
            a.aa("WebGridSelectionRangeEventArgs", () => new WebGridSelectionRangeEventArgsDescription());
            a.z("WebGridSelectionRangeEventArgs", WebGridSelectionRangeEventArgsDescriptionMetadata.a);
        }
    }
    WebGridSelectionRangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridSelectionRangeEventArgsDescriptionMetadata, 'WebGridSelectionRangeEventArgsDescriptionMetadata');
    WebGridSelectionRangeEventArgsDescriptionMetadata.a = null;
    return WebGridSelectionRangeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridSelectionRangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescriptionMetadata } from "./WebGridSelectionRangeDetailDescriptionMetadata";
import { WebGridSelectionRangeEventArgsDescription } from "./WebGridSelectionRangeEventArgsDescription";
/**
 * @hidden
 */
export let WebGridSelectionRangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSelectionRangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSelectionRangeEventArgsDescriptionMetadata.a == null) {
                WebGridSelectionRangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSelectionRangeEventArgsDescriptionMetadata.c(WebGridSelectionRangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGridSelectionRangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridSelectionRangeEventArgsDescriptionMetadata.a);
            WebGridSelectionRangeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSelectionRangeEventArgs");
            a.item("Detail", "ExportedType:WebGridSelectionRangeDetail");
        }
        static d(a) {
            WebGridSelectionRangeEventArgsDescriptionMetadata.b(a);
            a.ac("WebGridSelectionRangeEventArgs", () => new WebGridSelectionRangeEventArgsDescription());
            a.ab("WebGridSelectionRangeEventArgs", WebGridSelectionRangeEventArgsDescriptionMetadata.a);
        }
    }
    WebGridSelectionRangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridSelectionRangeEventArgsDescriptionMetadata, 'WebGridSelectionRangeEventArgsDescriptionMetadata');
    WebGridSelectionRangeEventArgsDescriptionMetadata.a = null;
    return WebGridSelectionRangeEventArgsDescriptionMetadata;
})();
